<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package dashy
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>

<head>
    <meta charset="<?php bloginfo('charset'); ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link rel="profile" href="https://gmpg.org/xfn/11">

    <?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
    <?php wp_body_open(); ?>
    <div id="page" class="site">
        <a class="skip-link screen-reader-text" href="#primary"><?php esc_html_e('Skip to content', 'dashy'); ?></a>
        <?php $header_image = esc_url(get_header_image());
        $header_class = ($header_image == "") ? '' : 'header-image';
        ?>


        <!-- header start -->
        <header class="site-header  <?php echo esc_attr($header_class); ?>"
            style="background-image:url(<?php echo esc_url($header_image) ?>); background-size: cover; background-position: center; background-repeat: no-repeat;">
            <div class="top-header">
                <div class="container">
                    <div class="top-header-in">
                        <ul class="social-list">
                            <?php
                        do_action('dashy_social_action')
                        ?>

                        </ul>

                        <div class="site-branding">
                            <?php
                                    the_custom_logo();
                                    if (is_front_page() && is_home()) :
                                        ?>
                            <h1 class="site-title"><a href="<?php echo esc_url(home_url('/')); ?>"
                                    rel="home"><?php bloginfo('name'); ?></a></h1>
                            <?php
                                    else :
                                        ?>
                            <p class="site-title"><a href="<?php echo esc_url(home_url('/')); ?>"
                                    rel="home"><?php bloginfo('name'); ?></a></p>
                            <?php
                                    endif;
                                    $dashy_description = get_bloginfo('description', 'display');
                                    if ($dashy_description || is_customize_preview()) :
                                ?>
                            <p class="site-description">
                                <?php echo esc_html($dashy_description); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped?>
                            </p>
                            <?php endif; ?>
                        </div><!-- .site-branding -->
                        <div class="top-header-right">

                            <div class="search-toggle">


                                <a href="#">
                                    <i class="fas fa-search"></i>
                                </a>

                                <?php get_search_form() ?>


                            </div>

                            
                        </div>
                    </div>
                 
                </div>
            </div>
            <div class="bottom-header">
                <div class="container">
                    <div class="bottom-header-in">
                        <a href="#" class="toggle-button open-button">
                            <span></span>
                            <span></span>
                            <span></span>
                            <span></span>
                        </a>
                        <div class="main-navigation-wrap">
                            <nav class="main-navigation">
                                <?php
                                    wp_nav_menu(
                                array(
                                            'theme_location' => 'menu-1',
                                            'menu_id'        => 'primary-menu',
                                        )
                            );
                                ?>
                            </nav>
                        </div>
                    </div>
                </div>

            </div>

        </header>